@@ -1,6 +1,6 @@
 from pydesy.gmath import *
 
-def perpendicular_baseline(s, basis, b):
+def perpendicular_baseline(s : float, basis : float, b : float) -> dict:
     if basis < 0:
         raise Exception("The basis with cannot be negative or equal to zero")
     g = asin(s / basis * sin(b))
