@@ -130,7 +130,7 @@ class TheodoliteCourse:
             "errors" : self.errors
         }
     
-    def save_report(self, fileName : string):
+    def save_report(self, fileName : str):
         with open(fileName, "w") as report:
             report.write(f"Report at {datetime.now()}\n")
             report.write("Points:\n\tName\tX\tY\tH\n")
